@@ -11,15 +11,15 @@ config() {
   # Otherwise, we leave the .new copy for the admin to consider...
 }
 # For future reference, if the change is ever reverted.  We need to remember "gnueabi" here.
-# config usr/lib/perl5/5.16.1/arm-linux-gnueabi-thread-multi/perllocal.pod.new
+# config usr/lib/perl5/5.18.1/arm-linux-gnueabi-thread-multi/perllocal.pod.new
 config usr/lib/perl5/perllocal.pod.new
-( cd usr/man/man1 ; rm -rf psed.1.gz.gz )
-( cd usr/man/man1 ; ln -sf s2p.1.gz.gz psed.1.gz.gz )
-( cd usr/man/man1 ; rm -rf pstruct.1.gz.gz )
-( cd usr/man/man1 ; ln -sf c2ph.1.gz.gz pstruct.1.gz.gz )
+( cd usr/man/man1 ; rm -rf psed.1.gz )
+( cd usr/man/man1 ; ln -sf s2p.1.gz psed.1.gz )
+( cd usr/man/man1 ; rm -rf pstruct.1.gz )
+( cd usr/man/man1 ; ln -sf c2ph.1.gz pstruct.1.gz )
 ( cd usr/bin ; rm -rf psed )
 ( cd usr/bin ; ln -sf s2p psed )
 ( cd usr/bin ; rm -rf perl )
-( cd usr/bin ; ln -sf perl5.16.1 perl )
+( cd usr/bin ; ln -sf perl5.18.1 perl )
 ( cd usr/bin ; rm -rf pstruct )
 ( cd usr/bin ; ln -sf c2ph pstruct )
